@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOHERTY;
 use strict;
 use warnings;
 # ABSTRACT: configure Dist::Zilla like DOHERTY
-our $VERSION = '0.40'; # VERSION
+our $VERSION = '0.41'; # VERSION
 
 
 use feature qw(say);
@@ -189,8 +189,8 @@ has dzil_files_for_scm => (
     default => sub {
         my $self = shift;
         return [
-            (qw/ Build.PL Makefile.PL /)x!$self->custom_build,
-            qw/ README README.mkdn /,
+            (qw/ Makefile.PL /)x!$self->custom_build,
+            qw/ README.mkdn /,
         ];
     },
 );
@@ -381,7 +381,7 @@ Dist::Zilla::PluginBundle::Author::DOHERTY - configure Dist::Zilla like DOHERTY
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -599,7 +599,7 @@ site near you, or see L<https://metacpan.org/module/Dist::Zilla::PluginBundle::A
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/doherty/Dist-Zilla-PluginBundle-Author-DOHERTY>
+The development version is on github at L<https://github.com/doherty/Dist-Zilla-PluginBundle-Author-DOHERTY>
 and may be cloned from L<git://github.com/doherty/Dist-Zilla-PluginBundle-Author-DOHERTY.git>
 
 =head1 BUGS AND LIMITATIONS
